==> qmmp_1.1.10.orig.tar.bz2: qmmp-1.1.10/src/plugins/Input/wildmidi/translations/wildmidi_plugin_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ru">
<context>
    <name>DecoderWildMidiFactory</name>
    <message>
        <location filename="../decoderwildmidifactory.cpp" line="61"/>
        <source>WildMidi Plugin</source>
        <translation>Модуль WildMidi</translation>
    </message>
    <message>
        <location filename="../decoderwildmidifactory.cpp" line="66"/>
        <source>Midi Files</source>
        <translation>Файлы midi</translation>
    </message>
    <message>
        <location filename="../decoderwildmidifactory.cpp" line="120"/>
        <source>About WildMidi Audio Plugin</source>
        <translation>Об аудио-модуле WildMdi</translation>
    </message>
    <message>
        <location filename="../decoderwildmidifactory.cpp" line="121"/>
        <source>Qmmp WildMidi Audio Plugin</source>
        <translation>Модуль WildMidi для Qmmp</translation>
    </message>
    <message>
        <location filename="../decoderwildmidifactory.cpp" line="122"/>
        <source>This plugin uses WildMidi library to play midi files</source>
        <translation>Для воспроизведения midi-файлов используется библиотека WildMidi</translation>
    </message>
    <message>
        <location filename="../decoderwildmidifactory.cpp" line="123"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Разработчик: Илья Котов &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>WildMidi Plugin Settings</source>
        <translation>Настройка модуля WildMidi</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="29"/>
        <source>Instrument configuration: </source>
        <translation>Настройки инструментов:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="43"/>
        <source>Sample rate:</source>
        <translation>Частота дискретизации:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="50"/>
        <source>Enhanced resampling</source>
        <translation>Улучшенная передискретизация</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="57"/>
        <source>Reverberation</source>
        <translation>Реверберация</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="39"/>
        <source>44100 Hz</source>
        <translation>44100 Гц</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="40"/>
        <source>48000 Hz</source>
        <translation>48000 Гц</translation>
    </message>
</context>
</TS>

==> qmmp_1.2.6.orig.tar.bz2: qmmp-1.2.6/src/plugins/Input/wildmidi/translations/wildmidi_plugin_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ru">
<context>
    <name>DecoderWildMidiFactory</name>
    <message>
        <location filename="../decoderwildmidifactory.cpp" line="50"/>
        <source>WildMidi Plugin</source>
        <translation>Модуль WildMidi</translation>
    </message>
    <message>
        <location filename="../decoderwildmidifactory.cpp" line="55"/>
        <source>Midi Files</source>
        <translation>Файлы midi</translation>
    </message>
    <message>
        <location filename="../decoderwildmidifactory.cpp" line="109"/>
        <source>About WildMidi Audio Plugin</source>
        <translation>Об аудио-модуле WildMdi</translation>
    </message>
    <message>
        <location filename="../decoderwildmidifactory.cpp" line="110"/>
        <source>Qmmp WildMidi Audio Plugin</source>
        <translation>Модуль WildMidi для Qmmp</translation>
    </message>
    <message>
        <location filename="../decoderwildmidifactory.cpp" line="111"/>
        <source>This plugin uses WildMidi library to play midi files</source>
        <translation>Для воспроизведения midi-файлов используется библиотека WildMidi</translation>
    </message>
    <message>
        <location filename="../decoderwildmidifactory.cpp" line="112"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Разработчик: Илья Котов &lt;forkotov02@ya.ru&gt;</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>WildMidi Plugin Settings</source>
        <translation>Настройка модуля WildMidi</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="29"/>
        <source>Instrument configuration: </source>
        <translation>Настройки инструментов:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="43"/>
        <source>Sample rate:</source>
        <translation>Частота дискретизации:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="50"/>
        <source>Enhanced resampling</source>
        <translation>Улучшенная передискретизация</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="57"/>
        <source>Reverberation</source>
        <translation>Реверберация</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="39"/>
        <source>44100 Hz</source>
        <translation>44100 Гц</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="40"/>
        <source>48000 Hz</source>
        <translation>48000 Гц</translation>
    </message>
</context>
</TS>
